==> ed2k-gtk-gui-0.6.2.tar.gz: ed2k-gtk-gui-0.6.2/ed2k_gui/notebook.h <==
/***************************************************************************
                          notebook.h  -  The main GUI notebook
                          ------------------------------------
    begin                : 2001
    copyright            : (C) 2001-2003 by Tim-Philipp Mller
    email                : t.i.m@orange.net
 ***************************************************************************/

/*
 *       functions to
 *         - create a notebook window
 *         - add a page to the notebook
 *
 */

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _ED2K_GUI_NOTEBOOK_H_INCLUDED_
#define _ED2K_GUI_NOTEBOOK_H_INCLUDED_

#include <gtk/gtkwidget.h>


enum
{
  NOTEBOOK_PAGE_DOWNLOADS = 0,
  NOTEBOOK_PAGE_UPLOADS,
  NOTEBOOK_PAGE_SEARCH,
  NOTEBOOK_PAGE_SERVERS,
  NOTEBOOK_PAGE_STATUS,
  NOTEBOOK_PAGE_OPTIONS,
  NOTEBOOK_PAGE_SHARED,
  NOTEBOOK_PAGE_STATS,
  NOTEBOOK_PAGE_LAST,
} ;

GtkWidget   *notebook_create (GtkPositionType pos);

void         notebook_show_hide_tab_label_text (void);

void         notebook_set_page (gint pagenum);

void         notebook_set_tab_pos (GtkPositionType pos);

void         notebook_set_overnet_mode (gboolean overnet);

#endif

==> ed2k-gtk-gui-0.6.3.tar.gz: ed2k-gtk-gui-0.6.3/ed2k_gui/notebook.h <==
/***************************************************************************
                          notebook.h  -  The main GUI notebook
                          ------------------------------------
    begin                : 2001
    copyright            : (C) 2001-2003 by Tim-Philipp Mller
    email                : t.i.m@orange.net
 ***************************************************************************/

/*
 *       functions to
 *         - create a notebook window
 *         - add a page to the notebook
 *
 */

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _ED2K_GUI_NOTEBOOK_H_INCLUDED_
#define _ED2K_GUI_NOTEBOOK_H_INCLUDED_

#include <gtk/gtkwidget.h>


enum
{
  NOTEBOOK_PAGE_DOWNLOADS = 0,
  NOTEBOOK_PAGE_UPLOADS,
  NOTEBOOK_PAGE_SEARCH,
  NOTEBOOK_PAGE_SERVERS,
  NOTEBOOK_PAGE_STATUS,
  NOTEBOOK_PAGE_OPTIONS,
  NOTEBOOK_PAGE_SHARED,
  NOTEBOOK_PAGE_STATS,
  NOTEBOOK_PAGE_LAST,
} ;

GtkWidget   *notebook_create (GtkPositionType pos, guint flags_disable_pages);

void         notebook_show_hide_tab_label_text (void);

void         notebook_set_page (gint pagenum);

void         notebook_set_tab_pos (GtkPositionType pos);

void         notebook_set_overnet_mode (gboolean overnet);

#endif
